# Changes

## [0.1.5] - 2024-04-07

### Features

* Added `homepage` to manifest.
* Added `rights` to manifest.
* Initialized `StudyGuide` as something that may be rendered from a manifest.

## [0.1.4] - 2024-04-05

### Features

* Canvases now have metadata.

### Bug Fixes

* Thumbnails: Both video and image canvases get thumbnails.
* navPlace: If location unknown, print error and pass.

### Minor Changes

* Manifests: Got rid of all hard-coded URIs.

## [0.1.3] - 2024-04-03

### Features

* Added artists to metadata.
* Added thumbnails to image canvases.

### Bug Fixes

* Made sure codes are not repeated in parent manifests.

## [0.1.2] - 2024-04-02

* Implemented change log.
* Added progress bar.
* Added navPlace.